@@ -2,7 +2,7 @@
  * vinagre-window-private.h
  * This file is part of vinagre
  *
- * Copyright (C) 2007 - Jonh Wendell <wendell@bani.com.br>
+ * Copyright (C) 2007,2008 - Jonh Wendell <wendell@bani.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __VINAGRE_WINDOW_PRIVATE_H__
@@ -44,9 +42,13 @@ struct _VinagreWindowPrivate
   GtkUIManager   *manager;
   GtkActionGroup *action_group;
   GtkActionGroup *always_sensitive_action_group;
-  GtkActionGroup *favorites_list_action_group;
-  guint           favorites_list_menu_ui_id;
-
+  GtkActionGroup *machine_connected_action_group;
+  GtkActionGroup *bookmarks_list_action_group;
+  GtkActionGroup *recent_action_group;
+  GtkAction      *recent_action;
+  guint           bookmarks_list_menu_ui_id;
+  guint           recents_menu_ui_id;
+  guint           update_recents_menu_ui_id;
 
   GtkWidget       *toolbar;
   GtkWidget       *menubar;
@@ -65,9 +67,11 @@ struct _VinagreWindowPrivate
   gboolean        fav_panel_visible;
 
   gulong	  signal_notebook;
+  gulong	  signal_clipboard;
 };
 
 
 G_END_DECLS
 
 #endif  /* __VINAGRE_WINDOW_PRIVATE_H__  */
+/* vim: ts=8 */
